@@ -518,22 +518,6 @@ class TestReactor(unittest.TestCase):
             ValueError,
             test_stl_filename_None)
 
-    def test_make_graveyard_accepts_offset_from_graveyard(self):
-        """Creates a graveyard for a reactor and sets the graveyard_offset.
-        Checks that the Reactor.graveyard_offset property is set"""
-
-        test_shape = paramak.RotateStraightShape(
-            points=[(0, 0), (0, 20), (20, 20)],
-            material_tag='mat1')
-        test_shape2 = paramak.RotateSplineShape(
-            points=[(0, 0), (0, 20), (20, 20)],
-            material_tag='mat2')
-        test_shape.rotation_angle = 360
-        test_reactor = paramak.Reactor([test_shape, test_shape2])
-        test_reactor.graveyard_offset == 101
-        graveyard = test_reactor.make_graveyard()
-        assert graveyard.volume > 0
-
     def test_reactor_creation_with_default_properties(self):
         """creates a Reactor object and checks that it has no default properties"""
 
@@ -1311,39 +1295,6 @@ class TestReactor(unittest.TestCase):
 
         self.assertRaises(ValueError, check_correct_error_is_rasied)
 
-    def test_cubit_h5m_export(self):
-        """exports a h5m file using cubit and checks that it has been created"""
-
-        os.system("rm test_dagmc.h5m")
-
-        my_reactor = paramak.BallReactor(
-            inner_bore_radial_thickness=10,
-            inboard_tf_leg_radial_thickness=30,
-            center_column_shield_radial_thickness=60,
-            divertor_radial_thickness=150,
-            inner_plasma_gap_radial_thickness=30,
-            plasma_radial_thickness=300,
-            outer_plasma_gap_radial_thickness=30,
-            firstwall_radial_thickness=30,
-            blanket_radial_thickness=50,
-            blanket_rear_wall_radial_thickness=30,
-            elongation=2,
-            triangularity=0.55,
-            number_of_tf_coils=16,
-            rotation_angle=90,
-            pf_coil_case_thicknesses=[10, 10, 10, 10],
-            pf_coil_radial_thicknesses=[20, 50, 50, 20],
-            pf_coil_vertical_thicknesses=[20, 50, 50, 20],
-            pf_coil_radial_position=[500, 575, 575, 500],
-            pf_coil_vertical_position=[300, 100, -100, -300],
-            rear_blanket_to_tf_gap=50,
-            outboard_tf_coil_radial_thickness=100,
-            outboard_tf_coil_poloidal_thickness=50
-        )
-        my_reactor.export_h5m_with_cubit(filename='test_dagmc.h5m')
-
-        assert Path('test_dagmc.h5m').is_file()
-
 
 if __name__ == "__main__":
     unittest.main()
